============================
``psyclone.psyir.backend.c``
============================

.. automodule:: psyclone.psyir.backend.c

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.backend.c
